Behaviour for loading prompts from directories, legacy config, or in-memory input.
Summary
Callbacks
@callback load(source :: term(), opts :: keyword()) :: {:ok, PromptRunner.Source.Result.t()} | {:error, term()}
Behaviour for loading prompts from directories, legacy config, or in-memory input.
@callback load(source :: term(), opts :: keyword()) :: {:ok, PromptRunner.Source.Result.t()} | {:error, term()}